==> open-xchange-server_6.10.0.0.orig.tar.gz: open-xchange-server-6.10.0.0/src/com/openexchange/ajax/writer/GroupWriter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.writer;

import java.util.TimeZone;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.ajax.fields.DataFields;
import com.openexchange.ajax.fields.GroupFields;
import com.openexchange.group.Group;
import com.openexchange.groupware.calendar.CalendarCollectionService;
import com.openexchange.server.services.ServerServiceRegistry;

/**
 * {@link GroupWriter} - Writes a group object into a JSON.
 * 
 * @author <a href="mailto:sebastian.kauss@open-xchange.com"">Sebastian
 *         Kauss</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class GroupWriter extends DataWriter {

    private final TimeZone utc;

    public GroupWriter() {
		super(null, null);
		utc = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class).getTimeZone("utc");
	}

	public void writeGroup(final Group group, final JSONObject json) throws JSONException {

        writeParameter(GroupFields.IDENTIFIER, group.getIdentifier(), json);
		writeParameter(GroupFields.DISPLAY_NAME, group.getDisplayName(), json);
		writeParameter(GroupFields.NAME, group.getSimpleName(), json);
        writeParameter(DataFields.LAST_MODIFIED_UTC, group.getLastModified(), utc, json);

        writeMembers(group, json);
	}

	protected void writeMembers(final Group group, final JSONObject json) throws JSONException {
		final JSONArray jsonArray = new JSONArray();
		for (final int member : group.getMember()) {
			jsonArray.put(member);
		}
		json.put(GroupFields.MEMBERS, jsonArray);
	}
}

==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/ajax/writer/GroupWriter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.writer;

import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
import java.util.TimeZone;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.fields.DataFields;
import com.openexchange.ajax.fields.GroupFields;
import com.openexchange.group.Group;

/**
 * {@link GroupWriter} - Writes a group object into a JSON.
 * 
 * @author <a href="mailto:sebastian.kauss@open-xchange.com"">Sebastian Kauss</a>
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class GroupWriter extends DataWriter {

    private final TimeZone utc;

    public GroupWriter() {
		super(null, null);
		utc = getTimeZone("utc");
	}

	public void writeGroup(final Group group, final JSONObject json) throws JSONException {

        writeParameter(GroupFields.IDENTIFIER, group.getIdentifier(), json);
		writeParameter(GroupFields.DISPLAY_NAME, group.getDisplayName(), json);
		writeParameter(GroupFields.NAME, group.getSimpleName(), json);
        writeParameter(DataFields.LAST_MODIFIED_UTC, group.getLastModified(), utc, json);

        writeMembers(group, json);
	}

	protected void writeMembers(final Group group, final JSONObject json) throws JSONException {
		final JSONArray jsonArray = new JSONArray();
		for (final int member : group.getMember()) {
			jsonArray.put(member);
		}
		json.put(GroupFields.MEMBERS, jsonArray);
	}
}
